import * as react from 'react';

type FetchOptions = RequestInit & {
    isCredentialsForCrossOrigin?: boolean;
    refetch?: number;
    retryAfter?: number;
};
type CustomError = {
    message: string;
    response: Response;
};

interface IUseIntersectionObserver {
    root?: HTMLElement | null;
    rootMargin?: string;
    threshold?: number;
    once?: boolean;
}

type LabelGetter = (label: string) => string | undefined;
type AllLabelsGetter = () => Record<string, string> | undefined;

declare const useFetch: (url: string, options?: FetchOptions) => {
    data: unknown;
    error: CustomError | null;
    loading: boolean;
};

declare const useIntersectionObserver: ({ root, rootMargin, threshold, once, }?: IUseIntersectionObserver) => {
    isIntersecting: boolean;
    ref: react.MutableRefObject<HTMLDivElement | null>;
};

declare const useDebounce: <T>(value: T, delay?: number) => T;

declare const useLocalStorage: <T>(key: string, initialState?: T | undefined) => [T, (value: T | null) => void];
declare const useSessionStorage: <T>(key: string, initialState?: T | undefined) => [T, (value: T | null) => void];

declare const useLocalizedContent: (url: string, fetchOptions?: FetchOptions) => [boolean, LabelGetter, AllLabelsGetter];

declare const useThrottle: <T>(value: T, delay?: number) => T;

export { useDebounce, useFetch, useIntersectionObserver, useLocalStorage, useLocalizedContent, useSessionStorage, useThrottle };
